@@ -1,6 +1,6 @@
 extern crate xml_oxide;
 
-use xml_oxide::{parser::OxideParser, sax::Event};
+use xml_oxide::{parser::Parser, sax::Event};
 
 use std::char;
 
@@ -21,7 +21,6 @@ use std::char;
 struct MyCollectorSaxHandler {
     start_counter: usize,
     end_counter: usize,
-    char_counter: usize,
     start_el_name_vec: Vec<String>,
     end_el_name_vec: Vec<String>,
     // characters should be collected because SAX parser can send them splitted for various reasons.
@@ -33,14 +32,13 @@ fn collect_with_parser<R: std::io::Read>(f: R) -> MyCollectorSaxHandler {
     let mut data = MyCollectorSaxHandler {
         start_counter: 0,
         end_counter: 0,
-        char_counter: 0,
         start_el_name_vec: Vec::new(),
         end_el_name_vec: Vec::new(),
         characters_collected_vec: Vec::new(),
         characters_buf: String::new(),
     };
 
-    let mut p = OxideParser::start(f);
+    let mut p = Parser::start(f);
 
     loop {
         let res = p.read_event();
@@ -61,11 +59,28 @@ fn collect_with_parser<R: std::io::Read>(f: R) -> MyCollectorSaxHandler {
                 }
                 Event::Characters(chars) => {
                     data.characters_buf.push_str(chars);
+                    data.characters_collected_vec.push(chars.to_string());
+                }
+                Event::Cdata(chars) => {
+                    data.characters_buf.push_str(chars);
+                }
+                Event::Reference(reference) => {
+                    println!(
+                        "raw: {:?} , resolved {:?}",
+                        reference.raw, reference.resolved
+                    );
+                    match reference.resolved {
+                        Some(resolved) => {
+                            data.characters_buf.push_str(resolved);
+                        }
+                        None => {}
+                    }
+                    // data.characters_buf.push_str(chars);
                 }
 
                 _ => {}
             },
-            Err(err) => {
+            Err(_err) => {
                 break;
             }
         }
@@ -91,7 +106,7 @@ fn test_basic() {
 }
 
 #[test]
-fn test_66_EntityRef() {
+fn test_66_entity_ref() {
     let c = char::from_u32(60).unwrap();
     // println!("{}", c);
     assert_eq!(c, '<'); //8898  &#x022C2;    60 &#x0003C;
@@ -104,38 +119,36 @@ fn test_66_EntityRef() {
 
     let data = collect_with_parser(s.as_bytes());
 
-    assert_eq!(data.characters_collected_vec.get(0).unwrap(), "1<2<3<4");
+    assert_eq!(data.characters_buf, "1<2<3<4");
     // assert_eq!(my_sax_handler.end, );
 }
 
 #[test]
-fn test_18_CDATA() {
+fn test_18_cdata() {
     let s = String::from(
         "<rootEl>1&lt;2&#60;3&#x0003C;4<![CDATA[ \
          1&lt;2&#60;3&#x0003C;4]]><![CDATA[]]></rootEl>",
     );
     let data = collect_with_parser(s.as_bytes());
 
-    println!("{}", data.characters_collected_vec.get(0).unwrap());
-    assert_eq!(
-        data.characters_collected_vec.get(0).unwrap(),
-        "1<2<3<4 1&lt;2&#60;3&#x0003C;4"
-    );
+    println!("{}", data.characters_buf);
+    assert_eq!(data.characters_buf, "1<2<3<4 1&lt;2&#60;3&#x0003C;4");
 }
 
 // comments should be ignored in content handler
 #[test]
-fn test_15_Comment() {
+fn test_15_comment() {
     let s = String::from("<rootEl>comments<!--are ignored--><!---->.</rootEl>");
     let data = collect_with_parser(s.as_bytes());
 
     println!("{}", data.characters_collected_vec.get(0).unwrap());
-    assert_eq!(data.characters_collected_vec.get(0).unwrap(), "comments.");
+    assert_eq!(data.characters_collected_vec.get(0).unwrap(), "comments");
+    assert_eq!(data.characters_collected_vec.get(1).unwrap(), ".");
 }
 
 #[test]
 #[should_panic]
-fn test_15_Comment_not_well_formed() {
+fn test_15_comment_not_well_formed() {
     let s = String::from(
         "<rootEl>comments<!-- are not well formed with 3 \
          hyphen at the end unless it is empty---><!---->.</rootEl>",
